#[repr(C)]pub struct strands {
pub magic: c_uint,
pub n: c_int,
pub p: *mut *const c_char,
}Expand description
VCL_STRANDS:
An argc+argv type of data structure where n indicates the number of strings in the p array. Individual components of a strands may be null.
A STRANDS allows you to work on a strings concatenation with the option to collect it into a single STRING, or if possible work directly on individual parts.
The memory management is very strict: a VMOD function receiving a STRANDS argument should keep no reference after the function returns. Retention of a STRANDS further in the ongoing task is undefined behavior and may result in a panic or data corruption.
Fields
magic: c_uintn: c_intp: *mut *const c_charTrait Implementations