vrt_blob

Struct vrt_blob 

#[repr(C)]
pub struct vrt_blob { pub magic: c_uint, pub type_: c_uint, pub len: usize, pub blob: *const c_void, }
VCL_BLOB:

Opaque, immutable data (pointer + length), minimum lifetime is the VCL task.

Type (optional) is owned by the creator of the blob. blob consumers may use it for checks, but should not assert on it.

The data behind the blob pointer is assumed to be immutable for the blob’s lifetime.

  • memory for shortlived blobs can be put on the tasks workspace

  • management of memory for longer lived blobs is up to the vmod (in which case the blob will probably be embedded in an object or referenced by other state with vcl lifetime)

Fields

magic: c_uinttype_: c_uintlen: usizeblob: *const c_void