BodyState

Enum BodyState 

pub enum BodyState {
    None,
    Error,
    Chunked,
    Length,
    Eof,
    Taken,
    Cached,
}
The state of a request or response body, mirroring Varnish’s body_status_t (see tbl/body_status.h).

Variants



None

No body.



Error

An error occurred while producing/reading the body.



Chunked

Chunked transfer encoding; the length isn’t known upfront.



Length

A known length (e.g. Content-Length).



Eof

The body ends when the connection closes; the length isn’t known upfront.



Taken

The body has already been consumed by someone else.



Cached

The body has been fully read and is cached as an object.