pub struct Backend<S: VclBackend<T>, T: VclResponse> { /* private fields */ }Expand description
Fat wrapper around VCL_BACKEND.
It will handle almost all the necessary boilerplate needed to create a custom backend. Most importantly,
it destroys/unregisters the backend as part of it’s Drop implementation, and
will convert the C methods to something more idiomatic.
Once created, a Backend’s sole purpose is to exist as a C reference for the VCL. As a
result, you don’t want to drop it until after all the transfers are done. The most common way
is just to have the backend be part of a vmod object because the object won’t be dropped until
the VCL is discarded and that can only happen once all the backend fetches are done.
Implementations
Sourceimpl<S: VclBackend<T>, T: VclResponse> Backend<S, T>
impl<S: VclBackend<T>, T: VclResponse> Backend<S, T>