BackendRef

Struct BackendRef 

pub struct BackendRef { /* private fields */ }
BackendRef can be created from a VCL_BACKEND and will handle proper refcounting. When dropped, the refcount will be decreased. This is the type that director vmods should use when storing backend references, instead of dealing with VCL_BACKEND directly.

Implementations

Source

impl BackendRef

pub unsafe fn new(bep: VCL_BACKEND) -> Option<Self>

Create a BackendRef from a VCL_BACKEND.

pub fn probe(&self, ctx: &Ctx<'_>) -> ProbeResult

Test the underlying backend for its health.

pub fn name(&self) -> &CStr

Return the VCL name of the underlying backend.

pub unsafe fn vcl_ptr(&self) -> VCL_BACKEND

Return the C pointer to the underlying backend.